hush.plugin package
===================

.. automodule:: hush.plugin
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hush.plugin.builtin

Submodules
----------

.. toctree::
   :maxdepth: 4

   hush.plugin.host
   hush.plugin.specs
